@@ -1,7 +1,12 @@
 from . import _version, core, types, utils
 from ._version import __version__  # noqa: F401
+from .configuration import (  # noqa: F401
+    parse_configuration,
+    register_configuration_provider,
+)
 from .core import (  # noqa: F401
     Command,
+    Context,
     FlattenParameterRenamer,
     Group,
     ParameterRenamer,
@@ -12,6 +17,10 @@ from .decorators import (  # noqa: F401  # noqa: F401
     configuration_option as configuration_option,
     group as group,
 )
-from .types import ClassUnion as ClassUnion, List as List  # noqa: F401  # noqa: F401
+from .types import (  # noqa: F401
+    AllParameters as AllParameters,
+    ClassUnion as ClassUnion,
+    List as List,
+)
 
 del _version  # noqa: F821
